@@ -5,8 +5,8 @@
 
 __name__ = 'blis'
 __title__ = 'blis'
-__version__ = '0.0.4'
-__summary__ = 'Cython bindings for Blis'
+__version__ = '0.0.5'
+__summary__ = 'Cython bindings for Blis linear algebra'
 __uri__ = 'https://github.com/spacy-io/cython-blis'
 __author__ = 'Matthew Honnibal'
 __email__ = 'honnibal@gmail.com'
